@@ -1,5 +1,5 @@
 /* -*- mode: C; mode: fold; -*- */
-/* Copyright (c) 1992, 1998 John E. Davis
+/* Copyright (c) 1992, 1998, 2000 John E. Davis
  * This file is part of JED editor library source.
  *
  * You may distribute this file under the terms the GNU General Public
@@ -1185,6 +1185,12 @@ void jed_set_buffer_flags (Buffer *b, unsigned int flags)
    b->flags &= BUFFER_MODIFIED;
    b->flags |= flags & ~BUFFER_MODIFIED;
    mark_buffer_modified (b, (int) modif, 1);
+#if 0
+   if ((b->flags & BUFFER_MODIFIED) != (flags & BUFFER_MODIFIED))
+     mark_buffer_modified (b, flags & BUFFER_MODIFIED, 1);
+
+   b->flags = flags;
+#endif
 }
 
 void check_line() /*{{{*/
