@@ -1,5 +1,5 @@
 /* -*- mode: C; mode: fold; -*- */
-/* Copyright (c) 1992, 1998 John E. Davis
+/* Copyright (c) 1992, 1998, 2000 John E. Davis
  * This file is part of JED editor library source.
  *
  * You may distribute this file under the terms the GNU General Public
@@ -481,7 +481,6 @@ static void get_buffer_info(void) /*{{{*/
 
 static void set_buffer_info(char *file, char *dir, char *name, int *flagsp) /*{{{*/
 {
-   unsigned int flags;
    char *tmp;
    Buffer *b;
    
@@ -508,12 +507,7 @@ static void set_buffer_info(char *file, char *dir, char *name, int *flagsp) /*{{
    if (name != b->name) 
      uniquely_name_buffer (b, name);
 
-   flags = (unsigned int)*flagsp;
-
-   if ((b->flags & BUFFER_MODIFIED) != (flags & BUFFER_MODIFIED))
-     mark_buffer_modified (b, flags & BUFFER_MODIFIED, 1);
-
-   b->flags = flags;
+   jed_set_buffer_flags (b, (unsigned int) *flagsp);
 }
 
 /*}}}*/
@@ -730,6 +724,7 @@ static SLang_Intrin_Fun_Type Jed_Intrinsics [] = /*{{{*/
 #ifndef SIXTEEN_BIT_SYSTEM
    MAKE_INTRINSIC_I("copy_region_to_kill_array", copy_region_to_kill_array, VOID_TYPE),
    MAKE_INTRINSIC_I("append_region_to_kill_array", append_region_to_kill_array, VOID_TYPE),
+   MAKE_INTRINSIC_I("prepend_region_to_kill_array", prepend_region_to_kill_array, VOID_TYPE),
    MAKE_INTRINSIC_I("insert_from_kill_array", insert_from_kill_array, VOID_TYPE),
 #endif     			       /* SIXTEEN_BIT_SYSTEM */
    MAKE_INTRINSIC_I("goto_column", goto_column, VOID_TYPE),
@@ -1015,7 +1010,7 @@ static SLang_Intrin_Var_Type Jed_Variables [] =
 #ifndef SIXTEEN_BIT_SYSTEM
    MAKE_VARIABLE("KILL_ARRAY_SIZE", &Kill_Array_Size, INT_TYPE, 1),
 #endif
-
+   MAKE_VARIABLE("_Backspace_Key", &_Jed_Backspace_Key, STRING_TYPE, 1),
 
    MAKE_VARIABLE(NULL, NULL, 0, 0)
 };
