@@ -1,5 +1,5 @@
 /* -*- mode: C; mode: fold; -*- */
-/* Copyright (c) 1992, 1998 John E. Davis
+/* Copyright (c) 1992, 1998, 2000 John E. Davis
  * This file is part of JED editor library source.
  *
  * You may distribute this file under the terms the GNU General Public
@@ -185,7 +185,7 @@ SLKeymap_Function_Type Jed_Functions[] = /*{{{*/
      {"quoted_insert", quoted_insert},
      {"redraw", redraw},
       /* {"replace", replace}, */
-     {"save_buffers", save_some_buffers},
+     {"save_some_buffers", save_some_buffers},
      {"scroll_left", scroll_left},
      {"scroll_right", scroll_right},
        /* {"search_backward", search_backward_cmd},
@@ -570,11 +570,13 @@ int do_key (void) /*{{{*/
 void do_jed(void) /*{{{*/
 {
    char *mode;
-   Buffer *tthis = CBuf;
+   Buffer *tthis;
+
+   tthis = CBuf;
+   mode = tthis->mode_string;
 
    /* Mark Undo boundary now because this might not be valid later */
    mark_undo_boundary (tthis);
-   mode = CBuf->mode_string;
 
    Repeat_Factor = NULL;
    Replace_Preserve_Case = 0;
@@ -586,7 +588,9 @@ void do_jed(void) /*{{{*/
    if (CBuf != JWindow->buffer)
      {
 	char *name;
-	if (buffer_exists(JWindow->buffer)) name = JWindow->buffer->name; else name = "*scratch*";
+	if (buffer_exists(JWindow->buffer))
+	  name = JWindow->buffer->name; 
+	else name = "*scratch*";
 	switch_to_buffer_cmd(name);
      }
 
@@ -603,11 +607,16 @@ void jed(void) /*{{{*/
    /* This routine is called from main.  So before actually strting, check
       one more hook to just to make sure  all things are go. */
    char *startup = ".()jed_startup_hook";
+   char *buffer_name;
 
 #if JED_HAS_TTY_MENUS
    jed_notify_menu_buffer_changed ();
 #endif
    
+   (void) jed_va_run_hooks ("_jed_switch_active_buffer_hooks", JED_HOOKS_RUN_ALL, 1, "");
+   /* This should not fail, and if it does it is not serious */
+   buffer_name = SLang_create_slstring (CBuf->name);
+
    if (2 == SLang_is_defined(startup + 3))
      {
 	SLang_run_hooks(startup + 3, 0);
@@ -639,6 +648,7 @@ void jed(void) /*{{{*/
    while(1)
      {
 	Suspend_Screen_Update = 0;
+
 	do_jed();
 	if (!SLKeyBoard_Quit && (CBuf->flags & BUFFER_MODIFIED)
 	    && (!Cursor_Motion)) CBuf->hits += 1;
@@ -647,7 +657,18 @@ void jed(void) /*{{{*/
 	     auto_save_buffer(CBuf);
 	     check_buffers();   /* check files on disk to see if they are recent */
 	  }
-	
+
+	if (buffer_name != CBuf->name)
+	  {
+	     (void) jed_va_run_hooks ("_jed_switch_active_buffer_hooks", JED_HOOKS_RUN_ALL, 1, buffer_name);
+	     SLang_free_slstring (buffer_name);    /* NULL ok */
+
+	     /* This should not fail because mode_string is an slstring, and if it
+	      * does fail, it is not important.
+	      */
+	     buffer_name = SLang_create_slstring (CBuf->name);
+	  }
+
 	if ((Last_Key_Function != (FVOID_STAR) ins_char_cmd)
 	    || (JWindow->trashed) || (JWindow != JWindow->next)
 	    || Suspend_Screen_Update ||
