@@ -1,5 +1,5 @@
 /* -*- mode: C; mode: fold; -*- */
-/* Copyright (c) 1992, 1998 John E. Davis
+/* Copyright (c) 1992, 1998, 2000 John E. Davis
  * This file is part of JED editor library source.
  *
  * You may distribute this file under the terms the GNU General Public
@@ -403,7 +403,14 @@ int write_buffer_cmd (char *filestr)
    SLfree (dir);
    SLfree (file);
 
-   return status;
+   if (status == -1)
+     return status;
+
+   /* This function is an intrinsic and is documented to return the 
+    * number of lines written out.
+    * 
+    */
+   return 0;
 }
 
 #if defined(__BORLANDC__) && !defined(MSWINDOWS)
@@ -523,7 +530,15 @@ int jed_get_mini_response (char *s)
 {
    int ch;
    int len;
-   
+
+   if (Batch)
+     {
+	if (EOF == fputs (s, stdout))
+	  exit_error ("Failed to write to stdout", 0);
+	
+	return jed_getkey ();
+     }
+	    
    len = strlen (s);
    if (len > Jed_Num_Screen_Cols)
      s += (len - Jed_Num_Screen_Cols);
@@ -780,6 +795,11 @@ static void create_minibuffer(void) /*{{{*/
    switch_to_buffer(MiniBuffer);
    MiniBuffer_Active = 1;
    erase_buffer ();
+
+#if JED_HAS_TTY_MENUS
+   jed_notify_menu_buffer_changed ();
+#endif
+
    /* allow kill region to kill to beginning of minibuffer. 
     * Suggested by stefen@uni-paderborn.de */
    push_mark ();
@@ -1401,7 +1421,10 @@ static VFILE *jed_open_lib_file (char *file) /*{{{*/
 	   || (file[1] == '\\')
 #endif
        ))
-     lib = "";
+     {
+	if (NULL == (lib = get_cwd ()))
+	  lib = "";
+     }
    else if ((lib == NULL) || (*lib == 0))
      exit_error("JED_ROOT environment variable needs set.", 0);
 
@@ -1542,7 +1565,19 @@ void load_buffer (void) /*{{{*/
    /* FIXME!!! This should be changed to use the filename if present.  
     * Otherwise, static objects will not get put in the proper table.
     */
-   if (NULL == (x = SLallocate_load_type (cbuf->name)))
+   if (cbuf->file[0] == 0)
+     x = SLallocate_load_type (cbuf->name);
+   else
+     {
+	char *file = jed_dir_file_merge (CBuf->dir, CBuf->file);
+	if (file == NULL)
+	  return;
+	
+	x = SLallocate_load_type (file);
+	SLfree (file);
+     }
+   
+   if (x == NULL)
      return;
 
    x->read = jed_read_from_buffer;
@@ -2196,6 +2231,7 @@ void init_minibuffer() /*{{{*/
        || (-1 == SLang_init_stdio ())
        || (-1 == SLang_init_posix_io ())
        || (-1 == SLang_init_ospath ())
+       /* || (-1 == SLang_init_import ()) */
        || (-1 == init_jed_intrinsics ())
        || (-1 == jed_init_userinfo ())
 #if JED_HAS_TTY_MENUS
