@@ -1,5 +1,5 @@
 /* Drop-down menus */
-/* Copyright (c) 1999 John E. Davis
+/* Copyright (c) 1999, 2000 John E. Davis
  * This file is part of JED editor library source.
  *
  * You may distribute this file under the terms the GNU General Public
@@ -1276,14 +1276,46 @@ static int draw_popup_menu (Menu_Popup_Type *p, int r, int c)
    return 0;
 }
 
+static Menu_Bar_Type *get_active_menubar (void)
+{
+   Menu_Bar_Type *b;
+
+   /* Active_Popup = NULL; */
+   b = Active_Menu_Bar;
+
+   if (b == NULL)
+     {
+	Buffer *buf = CBuf;
+
+	if (IS_MINIBUFFER)
+	  {
+	     if (NULL == (buf = jed_get_mini_action_buffer ()))
+	       return NULL;
+	  }
+
+	if (NULL == (b = buf->menubar))
+	  b = Global_Menu_Bar;
+
+	if (b == NULL)
+	  return NULL;
+	
+     }
+   /* Active_Popup = (Menu_Popup_Type *) b; */
+   return b;
+}
+
 int jed_redraw_menus (void)
 {
    Menu_Popup_Type *p;
    Menu_Bar_Type *b;
    int active;
 
+#if 0
    if (NULL == (b = CBuf->menubar))
      b = Global_Menu_Bar;
+#else
+   b = get_active_menubar ();
+#endif
 
    Active_Popup = (Menu_Popup_Type *) b;
 
@@ -1378,6 +1410,7 @@ int jed_exit_menu_bar (void)
 	Active_Popup = Active_Popup->parent;
      }
 
+   Active_Menu_Bar = NULL;
    Jed_Menus_Active = 0;
    return 1;
 }
@@ -1732,22 +1765,6 @@ SLang_Key_Type *jed_menu_do_key (void)
    return SLang_do_key (Menu_Keymap, jed_getkey);
 }
 
-static Menu_Bar_Type *get_active_menubar (void)
-{
-   Active_Popup = NULL;
-   if (Active_Menu_Bar == NULL)
-     {
-	if (NULL == (Active_Menu_Bar = CBuf->menubar))
-	  Active_Menu_Bar = Global_Menu_Bar;
-
-	if (Active_Menu_Bar == NULL)
-	  return NULL;
-     }
-
-   Active_Popup = (Menu_Popup_Type *) Active_Menu_Bar;
-   return Active_Menu_Bar;
-}
-
 static int exec_menubar_callback (Menu_Bar_Type *b, SLang_Name_Type **ntp)
 {
    SLang_Name_Type *nt;
@@ -1794,8 +1811,11 @@ int jed_select_menu_bar (void)
    Menu_Popup_Type *p;
    Menu_Node_Type **l, **lmax;
 
-   if (NULL == (p = (Menu_Popup_Type *) get_active_menubar ()))
+   if (NULL == (Active_Menu_Bar = get_active_menubar ()))
      return -1;
+   
+   p = (Menu_Popup_Type *) Active_Menu_Bar;
+   Active_Popup = p;
 
    l = p->subnodes;
    lmax = l + p->num_subnodes;
@@ -1818,7 +1838,10 @@ int jed_select_menu_bar (void)
    p->active_node = 0;
    
    if (-1 == exec_menubar_callback (Active_Menu_Bar, &Active_Menu_Bar->select_callback))
-     return -1;
+     {
+	jed_exit_menu_bar ();
+	return -1;
+     }
    
    (void) get_selected_menu_item (p);
    touch_screen ();
