@@ -1,5 +1,5 @@
 /* -*- mode: C; mode: fold; -*- */
-/* Copyright (c) 1992, 1998 John E. Davis
+/* Copyright (c) 1992, 1998, 2000 John E. Davis
  * This file is part of JED editor library source.
  *
  * You may distribute this file under the terms the GNU General Public
@@ -179,7 +179,10 @@ static void handle_interrupt (void)
 int init_tty (void) /*{{{*/
 {
    TTY_Termio_Type newtty;
-   
+   static char bskey[2];
+
+   bskey [1] = 0;
+
    if (Batch) return 0;
    if (X_Init_Term_Hook != NULL)
      {
@@ -223,6 +226,8 @@ int init_tty (void) /*{{{*/
    newtty.lt.t_dsuspc = 255;    /* to ignore ^Y */
    newtty.lt.t_lnextc = 255;
    newtty.s.sg_flags |= CBREAK;		/* do I want cbreak or raw????? */
+   bskey[0] = (char) newtty.s.sg_erase;
+   _Jed_Backspace_Key = bskey;
 #else
    
 #if NEED_BAUDRATES
@@ -257,6 +262,10 @@ int init_tty (void) /*{{{*/
    newtty.c_cc[VINTR] = Abort_Char;   /* ^G */
    newtty.c_cc[VQUIT] = NULL_VALUE;
    newtty.c_cc[VSUSP] = NULL_VALUE;   /* to ignore ^Z */
+
+   bskey [0] = (char) newtty.c_cc[VERASE];
+   _Jed_Backspace_Key = bskey;
+
 # ifdef VDSUSP
    newtty.c_cc[VDSUSP] = NULL_VALUE;   /* to ignore ^Y */
 # endif
