@@ -1,4 +1,4 @@
-/* Copyright (c) 1992, 1998 John E. Davis
+/* Copyright (c) 1992, 1998, 2000 John E. Davis
  * This file is part of JED editor library source.
  *
  * You may distribute this file under the terms the GNU General Public
@@ -1751,7 +1751,6 @@ LRESULT CALLBACK JEDWndProc(HWND hWnd, UINT msg, WPARAM wParam, LPARAM lParam)
 		  if (Ignore_User_Abort == 0) SLang_Error = USER_BREAK;
 		  SLKeyBoard_Quit = 1;
 	       }
-
 	     if (wParam == 0xE0) _putkey(wParam);
 	     _putkey(wParam);
 	     break;
@@ -2382,7 +2381,7 @@ int jed_init_w32_support (void)
    return w32_init_subprocess_support (1);
 }
 
-#if defined(__BORLANDC__) || defined(__VC__)
+#if defined(__BORLANDC__) || defined(__WIN32__)
 extern int main(int, char **);
 
 /* I do not think that this gets called.  Does it???? */
@@ -2436,10 +2435,9 @@ int PASCAL WinMain(HINSTANCE inst, HINSTANCE pinst, LPSTR lpszCmdLine, int nCmdS
 	       pt++;
 	  }
 	else
-#else
-	while ((*pt != '\0') && (*pt != ' '))
-	  pt++;			       /* advance until a space */
 #endif
+	  while ((*pt != '\0') && (*pt != ' '))
+	    pt++;			       /* advance until a space */
 
 	while (*pt == ' ')
 	  pt++;			       /* advance until a non-space */
