@@ -1,5 +1,5 @@
 /* -*- mode: C; mode: fold; -*- */
-/* Copyright (c) 1992, 1998 John E. Davis
+/* Copyright (c) 1992, 1998, 2000 John E. Davis
  * This file is part of JED editor library source.
  *
  * You may distribute this file under the terms the GNU General Public
@@ -78,6 +78,8 @@ static int JX_Ignore_Beep = 3;
 static int JX_Blink_Mode = 1;
 static int JX_MultiClick_Time = 500;   /* milliseconds */
 
+static int JX_MetaMask = Mod1Mask;
+
 #ifdef XJED_USE_R6IM
 static char *R6IM_Input_Method = NULL;
 static XIMStyle R6IM_Input_Style = 0;
@@ -1301,9 +1303,9 @@ static int X_process_events (int force, char *buf, unsigned int buflen,
 		  if (0 != (*n_chars = (int) *bufp++))
 		    {
 #if USE_NEW_META_CODE
-		       if (report.xkey.state & Mod1Mask)
+		       if (report.xkey.state & JX_MetaMask)
 			 {
-			    buf[0] = '\033' ;
+			    buf[0] = X_Alt_Char;
 			    SLMEMCPY (buf + 1, bufp, *n_chars);
 			    *n_chars += 1;
 			 }
@@ -1314,7 +1316,7 @@ static int X_process_events (int force, char *buf, unsigned int buflen,
 	       }
 	     else if (*n_chars == 1)
 	       {
-		  if (report.xkey.state & Mod1Mask)
+		  if (report.xkey.state & JX_MetaMask)
 		    {
 		       ch1 = *bufp;
 #if 0
@@ -1611,7 +1613,7 @@ static void set_wm_hints (JXWindow_Type *w, int xpos,  int ypos, unsigned long o
 
 static int alloc_color(char* color_name, XColor* color_info)
 {
-   static XColor exact_info;
+   XColor exact_info;
 
    if (XAllocNamedColor(This_XDisplay, XWin->color_map, color_name, color_info,
 			&exact_info))
@@ -2475,6 +2477,9 @@ static int read_and_insert_selection (Display *d, Window w, Atom property)
    while (bytes_after != 0)
      {
 	unsigned long bytes_read;
+	XTextProperty tp;
+	char **mb_data;
+	int mb_n;
 
 	if (Success != XGetWindowProperty (d, w, property, 
 					   total_bytes/4, 1 + bytes_after/4,
@@ -2484,10 +2489,25 @@ static int read_and_insert_selection (Display *d, Window w, Atom property)
 	  break;		       /* What the ?? */
 	
 	bytes_read = nitem * (actual_format/8);
-	(void) jed_ins_chars ((unsigned char *) data, bytes_read);
+
+        tp.value = data;
+	tp.encoding = actual_type;
+	tp.format = actual_format;
+	tp.nitems = nitem;
+	
+	if (Success == XmbTextPropertyToTextList(This_XDisplay, &tp, &mb_data, &mb_n))
+	  {
+	     int i;
+
+	     for (i=0; i < mb_n; i++)
+	       jed_ins_chars ((unsigned char *) mb_data[i], strlen (mb_data[i]));
+	     XFreeStringList (mb_data);
+	  }
+	else (void) jed_ins_chars (data, bytes_read);
 	total_bytes += bytes_read;
 	XFree (data);
      }
+
    return 0;
 }
 
@@ -2590,6 +2610,18 @@ static char *x_server_vendor (void)
    return The_Xserver_Vendor;
 }
 
+static void x_set_meta_keys (int *maskp)
+{
+   int mask = *maskp;
+
+   JX_MetaMask = 0;
+   if (mask & (1<<0)) JX_MetaMask |= Mod1Mask;
+   if (mask & (1<<1)) JX_MetaMask |= Mod2Mask;
+   if (mask & (1<<2)) JX_MetaMask |= Mod3Mask;
+   if (mask & (1<<3)) JX_MetaMask |= Mod4Mask;
+   if (mask & (1<<4)) JX_MetaMask |= Mod5Mask;
+}
+
 static SLang_Intrin_Fun_Type sl_x_table[] = /*{{{*/
 {
    MAKE_INTRINSIC_S("x_set_window_name", set_window_name, VOID_TYPE),
@@ -2635,6 +2667,7 @@ static SLang_Intrin_Fun_Type sl_x_table[] = /*{{{*/
    /* Prototype: String x_server_vendor ();
     * This function returns the vendor name of the X server.
     */
+   MAKE_INTRINSIC_I("x_set_meta_keys", x_set_meta_keys, SLANG_VOID_TYPE),
    MAKE_INTRINSIC(NULL,NULL,0,0)
 };
 
